# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..task.classified_interaction_request import ClassifiedInteractionRequest as ClassifiedInteractionRequest_9f72121b
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..task.interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from ..security.x_certificate import XCertificate as XCertificate_e55b0d3b

class CertificateValidationRequest(ClassifiedInteractionRequest_9f72121b):
    """
    Exception Class

    An error specifying an invalid certificate.

    See Also:
        `API CertificateValidationRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1CertificateValidationRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.CertificateValidationRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.ucb.CertificateValidationRequest'
    __pyunostruct__: str = 'com.sun.star.ucb.CertificateValidationRequest'

    typeName: str = 'com.sun.star.ucb.CertificateValidationRequest'
    """Literal Constant ``com.sun.star.ucb.CertificateValidationRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Classification: typing.Optional[InteractionClassification_6c4d10e7] = InteractionClassification_6c4d10e7.ERROR, CertificateValidity: typing.Optional[int] = 0, Certificate: typing.Optional[XCertificate_e55b0d3b] = None, HostName: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            CertificateValidity (int, optional): CertificateValidity value.
            Certificate (XCertificate, optional): Certificate value.
            HostName (str, optional): HostName value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Classification": Classification,
            "CertificateValidity": CertificateValidity,
            "Certificate": Certificate,
            "HostName": HostName,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._certificate_validity = kwargs["CertificateValidity"]
        self._certificate = kwargs["Certificate"]
        self._host_name = kwargs["HostName"]
        inst_keys = ('CertificateValidity', 'Certificate', 'HostName')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def CertificateValidity(self) -> int:
        """
        This value describes the validity of the certificate.
        """
        return self._certificate_validity
    
    @CertificateValidity.setter
    def CertificateValidity(self, value: int) -> None:
        self._certificate_validity = value

    @property
    def Certificate(self) -> XCertificate_e55b0d3b:
        """
        The certificate himself.
        """
        return self._certificate
    
    @Certificate.setter
    def Certificate(self, value: XCertificate_e55b0d3b) -> None:
        self._certificate = value

    @property
    def HostName(self) -> str:
        """
        The host name.
        """
        return self._host_name
    
    @HostName.setter
    def HostName(self, value: str) -> None:
        self._host_name = value


__all__ = ['CertificateValidationRequest']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .border_line import BorderLine as BorderLine_a3f80af6
from ..util.color import Color as Color_68e908c5
import typing


class BorderLine2(BorderLine_a3f80af6):
    """
    Struct Class

    A border line, extended with line style.
    
    **since**
    
        LibreOffice 3.4

    See Also:
        `API BorderLine2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1BorderLine2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.BorderLine2'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.table.BorderLine2'
    """Literal Constant ``com.sun.star.table.BorderLine2``"""

    def __init__(self, Color: typing.Optional[Color_68e908c5] = Color_68e908c5(0), InnerLineWidth: typing.Optional[int] = 0, OuterLineWidth: typing.Optional[int] = 0, LineDistance: typing.Optional[int] = 0, LineStyle: typing.Optional[int] = 0, LineWidth: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Color (Color, optional): Color value.
            InnerLineWidth (int, optional): InnerLineWidth value.
            OuterLineWidth (int, optional): OuterLineWidth value.
            LineDistance (int, optional): LineDistance value.
            LineStyle (int, optional): LineStyle value.
            LineWidth (int, optional): LineWidth value.
        """

        if isinstance(Color, BorderLine2):
            oth: BorderLine2 = Color
            self.Color = oth.Color
            self.InnerLineWidth = oth.InnerLineWidth
            self.OuterLineWidth = oth.OuterLineWidth
            self.LineDistance = oth.LineDistance
            self.LineStyle = oth.LineStyle
            self.LineWidth = oth.LineWidth
            return

        kargs = {
            "Color": Color,
            "InnerLineWidth": InnerLineWidth,
            "OuterLineWidth": OuterLineWidth,
            "LineDistance": LineDistance,
            "LineStyle": LineStyle,
            "LineWidth": LineWidth,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._line_style = kwargs["LineStyle"]
        self._line_width = kwargs["LineWidth"]
        inst_keys = ('LineStyle', 'LineWidth')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def LineStyle(self) -> int:
        """
        Style of the border.
        """
        return self._line_style

    @LineStyle.setter
    def LineStyle(self, value: int) -> None:
        self._line_style = value

    @property
    def LineWidth(self) -> int:
        """
        Width of the border, this is the base to compute all the lines and gaps widths.
        
        These widths computations are based on the LineStyle property
        
        This property is prevailing on the old Out, In and Dist width from BorderLine. If this property is set to 0, then the other widths will be used to guess the border width.
        """
        return self._line_width

    @LineWidth.setter
    def LineWidth(self, value: int) -> None:
        self._line_width = value


__all__ = ['BorderLine2']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.control
from __future__ import annotations
from ...awt.uno_control_check_box import UnoControlCheckBox as UnoControlCheckBox_ef690d6e
from ..x_bound_control import XBoundControl as XBoundControl_bba00bed

class CheckBox(UnoControlCheckBox_ef690d6e, XBoundControl_bba00bed):
    """
    Service Class

    describes a check box control which can (but not necessarily has to) be bound to a database field.
    
    The model of the control has to support the com.sun.star.form.component.CheckBox service.

    See Also:
        `API CheckBox <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CheckBox.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.control'
    __ooo_full_ns__: str = 'com.sun.star.form.control.CheckBox'
    __ooo_type_name__: str = 'service'


__all__ = ['CheckBox']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty
from .fill_properties import FillProperties as FillProperties_f1200da8
from .line_properties import LineProperties as LineProperties_f13f0da9
from .rotation_descriptor import RotationDescriptor as RotationDescriptor_2cec0f63
from .shadow_properties import ShadowProperties as ShadowProperties_e350e87
from .shape import Shape as Shape_85cc09e5
from .text import Text as Text_7c140999
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class CustomShape(FillProperties_f1200da8, LineProperties_f13f0da9, RotationDescriptor_2cec0f63, ShadowProperties_e350e87, Shape_85cc09e5, Text_7c140999):
    """
    Service Class

    This service is for a CustomShape.

    See Also:
        `API CustomShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.CustomShape'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CustomShapeGeometry(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        This property describes the geometry of the CustomShape.
        
        The CustomShapeEngine that is used should be able to get on with the content of this property.
        
        If the CustomShapeEngine property is \"com.sun.star.drawing.EnhancedCustomShapeEngine\", then this property is containing properties as they are specified in the service com.sun.star.drawing.EnhancedCustomShapeGeometry
        """
        ...

    @abstractproperty
    def CustomShapeData(self) -> str:
        """
        This property can be used to store data that the CustomShapeEngine may use for rendering.
        """
        ...

    @abstractproperty
    def CustomShapeEngine(self) -> str:
        """
        This property contains the CustomShapeEngine service name that has to be used for rendering.
        """
        ...

    @abstractproperty
    def CustomShapeReplacementURL(self) -> str:
        """
        This property describes the URL to a replacement graphic that could be displayed if the CustomShape engine is not available.
        """
        ...


__all__ = ['CustomShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class DatabaseRegistrationEvent(EventObject_a3d70b03):
    """
    Struct Class

    describes a change in a database registration
    
    **since**
    
        LibreOffice 3.3

    See Also:
        `API DatabaseRegistrationEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sdb_1_1DatabaseRegistrationEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DatabaseRegistrationEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sdb.DatabaseRegistrationEvent'
    """Literal Constant ``com.sun.star.sdb.DatabaseRegistrationEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Name: typing.Optional[str] = '', OldLocation: typing.Optional[str] = '', NewLocation: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Name (str, optional): Name value.
            OldLocation (str, optional): OldLocation value.
            NewLocation (str, optional): NewLocation value.
        """

        if isinstance(Source, DatabaseRegistrationEvent):
            oth: DatabaseRegistrationEvent = Source
            self.Source = oth.Source
            self.Name = oth.Name
            self.OldLocation = oth.OldLocation
            self.NewLocation = oth.NewLocation
            return

        kargs = {
            "Source": Source,
            "Name": Name,
            "OldLocation": OldLocation,
            "NewLocation": NewLocation,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._old_location = kwargs["OldLocation"]
        self._new_location = kwargs["NewLocation"]
        inst_keys = ('Name', 'OldLocation', 'NewLocation')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Name(self) -> str:
        """
        is the name of the database registration affected by the event
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def OldLocation(self) -> str:
        """
        is the old location of the database which is affected by the event
        """
        return self._old_location

    @OldLocation.setter
    def OldLocation(self, value: str) -> None:
        self._old_location = value

    @property
    def NewLocation(self) -> str:
        """
        is the new location of the database which is affected by the event
        """
        return self._new_location

    @NewLocation.setter
    def NewLocation(self, value: str) -> None:
        self._new_location = value


__all__ = ['DatabaseRegistrationEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xsd
from __future__ import annotations
from abc import abstractmethod, abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XDataType(XPropertySet_bc180bfa):
    """
    specifies an XSD compliant simple data type

    See Also:
        `API XDataType <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xsd_1_1XDataType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xsd'
    __ooo_full_ns__: str = 'com.sun.star.xsd.XDataType'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xsd.XDataType'

    @abstractmethod
    def explainInvalid(self, value: str) -> str:
        """
        TODO.
        """
        ...
    @abstractmethod
    def validate(self, value: str) -> bool:
        """
        TODO.
        """
        ...
    @abstractproperty
    def IsBasic(self) -> bool:
        """
        specifies whether the type is a basic type
        
        Basic types are built into the type system, and cannot be changed by the user.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        provides access to the name of the type
        """
        ...

    @abstractproperty
    def Pattern(self) -> str:
        """
        specifies the pattern which strings conforming to this type comply to
        
        See http://www.w3.org/TR/xmlschema-2/#rf-pattern
        """
        ...

    @abstractproperty
    def TypeClass(self) -> int:
        """
        class of the type
        """
        ...

    @abstractproperty
    def WhiteSpaceTreatment(self) -> int:
        """
        specifies how strings of this data type are to be processed, with respect to white spaces
        
        See http://www.w3.org/TR/xmlschema-2/#rf-whiteSpace
        """
        ...


__all__ = ['XDataType']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_properties_change_listener import XPropertiesChangeListener as XPropertiesChangeListener_7a7d1122
    from .x_property_set_info import XPropertySetInfo as XPropertySetInfo_efa90d86

class XMultiPropertySet(XInterface_8f010a43):
    """
    provides access to multiple properties with a single call.

    See Also:
        `API XMultiPropertySet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XMultiPropertySet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XMultiPropertySet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XMultiPropertySet'

    @abstractmethod
    def addPropertiesChangeListener(self, aPropertyNames: typing.Tuple[str, ...], xListener: XPropertiesChangeListener_7a7d1122) -> None:
        """
        adds an XPropertiesChangeListener to the specified property with the specified names.
        
        The implementation can ignore the names of the properties and fire the event on all properties.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...
    @abstractmethod
    def firePropertiesChangeEvent(self, aPropertyNames: typing.Tuple[str, ...], xListener: XPropertiesChangeListener_7a7d1122) -> None:
        """
        fires a sequence of PropertyChangeEvents to the specified listener.
        """
        ...
    @abstractmethod
    def getPropertySetInfo(self) -> XPropertySetInfo_efa90d86:
        """
        """
        ...
    @abstractmethod
    def getPropertyValues(self, aPropertyNames: typing.Tuple[str, ...]) -> typing.Tuple[object, ...]:
        """
        The order of the values in the returned sequence will be the same as the order of the names in the argument.
        """
        ...
    @abstractmethod
    def removePropertiesChangeListener(self, xListener: XPropertiesChangeListener_7a7d1122) -> None:
        """
        removes an XPropertiesChangeListener from the listener list.
        
        It is a \"noop\" if the listener is not registered.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...
    @abstractmethod
    def setPropertyValues(self, aPropertyNames: typing.Tuple[str, ...], aValues: typing.Tuple[object, ...]) -> None:
        """
        sets the values to the properties with the specified names.
        
        The values of the properties must change before the bound events are fired. The values of the constrained properties should change after the vetoable events are fired and only if no exception occurred. Unknown properties are ignored.

        Raises:
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XMultiPropertySet']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..table.x_cell import XCell as XCell_70d408e8
    from ..table.x_cell_range import XCellRange as XCellRange_a2f70ad5

class XCellRangesAccess(XInterface_8f010a43):
    """
    provides access to the cells or to sub-ranges of all sheets.

    See Also:
        `API XCellRangesAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangesAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XCellRangesAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XCellRangesAccess'

    @abstractmethod
    def getCellByPosition(self, nColumn: int, nRow: int, nSheet: int) -> XCell_70d408e8:
        """
        Returns a single cell within the range.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getCellRangeByPosition(self, nLeft: int, nTop: int, nRight: int, nBottom: int, nSheet: int) -> XCellRange_a2f70ad5:
        """
        Returns a sub-range of cells within the range.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getCellRangesByName(self, aRange: str) -> typing.Tuple[XCellRange_a2f70ad5, ...]:
        """
        Returns a sub-range of cells within the range.
        
        The sub-range is specified by its name. The format of the range name is dependent of the context of the table. In spreadsheets valid names may be \"Sheet1.A1:C5\" or \"$Sheet1.$B$2\" or even defined names for cell ranges such as \"MySpecialCell\".

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XCellRangesAccess']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .point import Point as Point_5fb2085e
from .rectangle import Rectangle as Rectangle_84b109e9


class DockingEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies a docking event.

    See Also:
        `API DockingEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1DockingEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.DockingEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.DockingEvent'
    """Literal Constant ``com.sun.star.awt.DockingEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, TrackingRectangle: typing.Optional[Rectangle_84b109e9] = UNO_NONE, MousePos: typing.Optional[Point_5fb2085e] = UNO_NONE, bLiveMode: typing.Optional[bool] = False, bInteractive: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            TrackingRectangle (Rectangle, optional): TrackingRectangle value.
            MousePos (Point, optional): MousePos value.
            bLiveMode (bool, optional): bLiveMode value.
            bInteractive (bool, optional): bInteractive value.
        """

        if isinstance(Source, DockingEvent):
            oth: DockingEvent = Source
            self.Source = oth.Source
            self.TrackingRectangle = oth.TrackingRectangle
            self.MousePos = oth.MousePos
            self.bLiveMode = oth.bLiveMode
            self.bInteractive = oth.bInteractive
            return

        kargs = {
            "Source": Source,
            "TrackingRectangle": TrackingRectangle,
            "MousePos": MousePos,
            "bLiveMode": bLiveMode,
            "bInteractive": bInteractive,
        }
        if kargs["TrackingRectangle"] is UNO_NONE:
            kargs["TrackingRectangle"] = None
        if kargs["MousePos"] is UNO_NONE:
            kargs["MousePos"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._tracking_rectangle = kwargs["TrackingRectangle"]
        self._mouse_pos = kwargs["MousePos"]
        self._b_live_mode = kwargs["bLiveMode"]
        self._b_interactive = kwargs["bInteractive"]
        inst_keys = ('TrackingRectangle', 'MousePos', 'bLiveMode', 'bInteractive')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def TrackingRectangle(self) -> Rectangle_84b109e9:
        """
        specifies the current tracking rectangle
        """
        return self._tracking_rectangle

    @TrackingRectangle.setter
    def TrackingRectangle(self, value: Rectangle_84b109e9) -> None:
        self._tracking_rectangle = value

    @property
    def MousePos(self) -> Point_5fb2085e:
        """
        specifies the current mouse position in frame coordinates
        """
        return self._mouse_pos

    @MousePos.setter
    def MousePos(self, value: Point_5fb2085e) -> None:
        self._mouse_pos = value

    @property
    def bLiveMode(self) -> bool:
        """
        specifies if the layout should be adjusted immediately
        """
        return self._b_live_mode

    @bLiveMode.setter
    def bLiveMode(self, value: bool) -> None:
        self._b_live_mode = value

    @property
    def bInteractive(self) -> bool:
        """
        specifies if the docking procedure is interactive which means that the user is currently dragging the window to a new position if this member is FALSE the window will be docked or undocked immediately using the returned tracking rectangle
        """
        return self._b_interactive

    @bInteractive.setter
    def bInteractive(self, value: bool) -> None:
        self._b_interactive = value


__all__ = ['DockingEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .window_event import WindowEvent as WindowEvent_9a2b0ace
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XWindowListener(XEventListener_c7230c4a):
    """
    makes it possible to receive window events.
    
    Component events are provided only for notification purposes. Moves and resizes will be handled internally by the window component, so that GUI layout works properly regardless of whether a program registers such a listener or not.

    See Also:
        `API XWindowListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XWindowListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XWindowListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XWindowListener'

    @abstractmethod
    def windowHidden(self, e: EventObject_a3d70b03) -> None:
        """
        is invoked when the window has been hidden.
        """
        ...
    @abstractmethod
    def windowMoved(self, e: WindowEvent_9a2b0ace) -> None:
        """
        is invoked when the window has been moved.
        """
        ...
    @abstractmethod
    def windowResized(self, e: WindowEvent_9a2b0ace) -> None:
        """
        is invoked when the window has been resized.
        """
        ...
    @abstractmethod
    def windowShown(self, e: EventObject_a3d70b03) -> None:
        """
        is invoked when the window has been shown.
        """
        ...

__all__ = ['XWindowListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from abc import abstractproperty
from .content_result_set import ContentResultSet as ContentResultSet_d4ee0cc8

class CachedContentResultSet(ContentResultSet_d4ee0cc8):
    """
    Service Class

    is used on client side to access a ContentResultSet remote optimized.
    
    The CachedContentResultSet will not load every single property or even row just in that moment you ask for it, but load the data for some rows beforehand.
    
    Every time when a new package of data is loaded, the so far loaded data will be released, so the cash will not grow and grow and grow.

    See Also:
        `API CachedContentResultSet <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1CachedContentResultSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.CachedContentResultSet'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def FetchDirection(self) -> int:
        """
        contains the direction for fetching rows from an underlying database.
        
        The value can be one of the com.sun.star.sdbc.FetchDirection constants group.
        
        The default value is implementation specific.
        
        If you set the value to com.sun.star.sdbc.FetchDirection.UNKNOWN an implementation specific direction will be used.
        """
        ...

    @abstractproperty
    def FetchSize(self) -> int:
        """
        contains the number of result set rows that should be fetched from an underlying database.
        
        The default fetch size is implementation specific.
        
        Every negative value for parameter FetchSize will force an implementation specific value to be set.
        """
        ...


__all__ = ['CachedContentResultSet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from .x_driver_access import XDriverAccess as XDriverAccess_b9ec0bba
from .x_driver_manager import XDriverManager as XDriverManager_c6470c23

class XDriverManager2(XEnumerationAccess_4bac0ffc, XDriverAccess_b9ec0bba, XDriverManager_c6470c23):
    """
    is the basic interface for managing a set of SDBC drivers.
    
    As part of its initialization, the DriverManager service will attempt to load the registered drivers.
    
    When the method getConnection is called, the DriverManager will attempt to locate a suitable driver.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XDriverManager2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDriverManager2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XDriverManager2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XDriverManager2'


__all__ = ['XDriverManager2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_frame import XFrame as XFrame_7a570956
if typing.TYPE_CHECKING:
    from .x_frames import XFrames as XFrames_842009c9

class XFramesSupplier(XFrame_7a570956):
    """
    provides access to sub frames of current one

    See Also:
        `API XFramesSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XFramesSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XFramesSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XFramesSupplier'

    @abstractmethod
    def getActiveFrame(self) -> XFrame_7a570956:
        """
        gets the current active frame of this container (not of any other available supplier)
        
        This may be the frame itself. The active frame is defined as the frame which contains (recursively) the window with the focus. If no window within the frame contains the focus, this method returns the last frame which had the focus. If no containing window ever had the focus, the first frame within this frame is returned.
        """
        ...
    @abstractmethod
    def getFrames(self) -> XFrames_842009c9:
        """
        provides access to this container and to all other XFramesSupplier which are available from this node of frame tree
        """
        ...
    @abstractmethod
    def setActiveFrame(self, Frame: XFrame_7a570956) -> None:
        """
        is called on activation of a direct sub-frame.
        
        This method is only allowed to be called by a sub-frame according to XFrame.activate() or XFramesSupplier.setActiveFrame(). After this call XFramesSupplier.getActiveFrame() will return the frame specified by Frame.
        
        In general this method first calls the method XFramesSupplier.setActiveFrame() at the creator frame with this as the current argument. Then it broadcasts the FrameActionEvent FrameAction.FRAME_ACTIVATED.
        
        Note: Given parameter Frame must already exist inside the container (e.g., inserted by using XFrames.append())
        """
        ...

__all__ = ['XFramesSupplier']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uno
from __future__ import annotations
from abc import abstractmethod, ABC

class XInterface(ABC):
    """
    base interface of all UNO interfaces
    
    It provides lifetime control by reference counting and the possibility of querying for other interfaces of the same logical object.
    
    \"Logical Object\" in this case means that the interfaces actually can be supported by internal (e.g. aggregated) physical objects.
    
    Deriving from this interface is mandatory for all UNO interfaces.
    
    Each language binding (Java, C++, StarBasic, Python, ... ) may provide a different mapping of this interface, please look into the language dependent documentation.
    
    The UNO object does not export the state of the reference count (acquire() and release() do not have return values). In general, also the UNO object itself should not make any assumption on the concrete value of the reference count (except on the transition from one to zero ).

    See Also:
        `API XInterface <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uno_1_1XInterface.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uno'
    __ooo_full_ns__: str = 'com.sun.star.uno.XInterface'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.uno.XInterface'

    @abstractmethod
    def acquire(self) -> None:
        """
        increases the reference counter by one.
        
        When you have called acquire() on the UNO object, it is often said, that you have a reference or a hard reference to the object.
        
        It is only allowed to invoke a method on a UNO object, when you keep a hard reference to it.
        
        Every call to acquire must be followed by a corresponding call to release some time later, which may eventually lead to the destruction of the object.
        """
        ...
    @abstractmethod
    def queryInterface(self, aType: object) -> object:
        """
        queries for a new interface to an existing UNO object.
        
        The queryInterface() method is the entry point to obtain other interfaces which are exported by the object. The caller asks the implementation of the object, if it supports the interface specified by the type argument. The call may either return with an interface reference of the requested type or with a void any.
        
        There are certain specifications, a queryInterface() implementation must not violate.
        
        1) If queryInterface on a specific object has once returned a valid interface reference for a given type, it must return a valid reference for any successive queryInterface calls on this object for the same type.
        
        2) If queryInterface on a specific object has once returned a null reference for a given type, it must always return a null reference for the same type.
        
        3) If queryInterface on a reference A returns reference B, queryInterface on B for Type A must return interface reference A or calls made on the returned reference must be equivalent to calls made on reference A.
        
        4) If queryInterface on a reference A returns reference B, queryInterface on A and B for XInterface must return the same interface reference (object identity).
        
        The reason for the strong specification is, that a Uno Runtime Environment (URE) may choose to cache queryInterface() calls.
        
        As mentioned above, certain language bindings may map this function differently also with different specifications, please visit the language dependent specification for it. The current C++ binding sticks to the specification state
        
        The rules mentioned above are basically identical to the rules of QueryInterface in MS COM.
        """
        ...
    @abstractmethod
    def release(self) -> None:
        """
        decreases the reference counter by one.
        
        When the reference counter reaches 0, the object gets deleted.
        
        Calling release() on the object is often called releasing or clearing the reference to an object.
        """
        ...

__all__ = ['XInterface']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .gradient_style import GradientStyle as GradientStyle_b02b0b93
from ..util.color import Color as Color_68e908c5


class Gradient(object):
    """
    Struct Class

    Describes a gradient between two colors.
    
    Many aspects of the gradient are undefined, like the algorithm and color space to use to interpolate between the colors and what \"intensity\" means.

    See Also:
        `API Gradient <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1Gradient.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.Gradient'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.Gradient'
    """Literal Constant ``com.sun.star.awt.Gradient``"""

    def __init__(self, Style: typing.Optional[GradientStyle_b02b0b93] = GradientStyle_b02b0b93.LINEAR, StartColor: typing.Optional[Color_68e908c5] = Color_68e908c5(0), EndColor: typing.Optional[Color_68e908c5] = Color_68e908c5(0), Angle: typing.Optional[int] = 0, Border: typing.Optional[int] = 0, XOffset: typing.Optional[int] = 0, YOffset: typing.Optional[int] = 0, StartIntensity: typing.Optional[int] = 0, EndIntensity: typing.Optional[int] = 0, StepCount: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Style (GradientStyle, optional): Style value.
            StartColor (Color, optional): StartColor value.
            EndColor (Color, optional): EndColor value.
            Angle (int, optional): Angle value.
            Border (int, optional): Border value.
            XOffset (int, optional): XOffset value.
            YOffset (int, optional): YOffset value.
            StartIntensity (int, optional): StartIntensity value.
            EndIntensity (int, optional): EndIntensity value.
            StepCount (int, optional): StepCount value.
        """
        super().__init__()

        if isinstance(Style, Gradient):
            oth: Gradient = Style
            self.Style = oth.Style
            self.StartColor = oth.StartColor
            self.EndColor = oth.EndColor
            self.Angle = oth.Angle
            self.Border = oth.Border
            self.XOffset = oth.XOffset
            self.YOffset = oth.YOffset
            self.StartIntensity = oth.StartIntensity
            self.EndIntensity = oth.EndIntensity
            self.StepCount = oth.StepCount
            return

        kargs = {
            "Style": Style,
            "StartColor": StartColor,
            "EndColor": EndColor,
            "Angle": Angle,
            "Border": Border,
            "XOffset": XOffset,
            "YOffset": YOffset,
            "StartIntensity": StartIntensity,
            "EndIntensity": EndIntensity,
            "StepCount": StepCount,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._style = kwargs["Style"]
        self._start_color = kwargs["StartColor"]
        self._end_color = kwargs["EndColor"]
        self._angle = kwargs["Angle"]
        self._border = kwargs["Border"]
        self._x_offset = kwargs["XOffset"]
        self._y_offset = kwargs["YOffset"]
        self._start_intensity = kwargs["StartIntensity"]
        self._end_intensity = kwargs["EndIntensity"]
        self._step_count = kwargs["StepCount"]


    @property
    def Style(self) -> GradientStyle_b02b0b93:
        """
        specifies the style of the gradient.
        """
        return self._style

    @Style.setter
    def Style(self, value: GradientStyle_b02b0b93) -> None:
        self._style = value

    @property
    def StartColor(self) -> Color_68e908c5:
        """
        specifies the color at the start point of the gradient.
        """
        return self._start_color

    @StartColor.setter
    def StartColor(self, value: Color_68e908c5) -> None:
        self._start_color = value

    @property
    def EndColor(self) -> Color_68e908c5:
        """
        specifies the color at the end point of the gradient.
        """
        return self._end_color

    @EndColor.setter
    def EndColor(self, value: Color_68e908c5) -> None:
        self._end_color = value

    @property
    def Angle(self) -> int:
        """
        angle of the gradient in 1/10 degree.
        """
        return self._angle

    @Angle.setter
    def Angle(self, value: int) -> None:
        self._angle = value

    @property
    def Border(self) -> int:
        """
        per cent of the total width where just the start color is used.
        """
        return self._border

    @Border.setter
    def Border(self, value: int) -> None:
        self._border = value

    @property
    def XOffset(self) -> int:
        """
        Specifies the X-coordinate, where the gradient begins.
        
        This is effectively the center of the RADIAL, ELLIPTICAL, SQUARE and RECT style gradients.
        """
        return self._x_offset

    @XOffset.setter
    def XOffset(self, value: int) -> None:
        self._x_offset = value

    @property
    def YOffset(self) -> int:
        """
        Specifies the Y-coordinate, where the gradient begins.
        
        See previous field.
        """
        return self._y_offset

    @YOffset.setter
    def YOffset(self, value: int) -> None:
        self._y_offset = value

    @property
    def StartIntensity(self) -> int:
        """
        Specifies the intensity at the start point of the gradient.
        
        What that means is undefined.
        """
        return self._start_intensity

    @StartIntensity.setter
    def StartIntensity(self, value: int) -> None:
        self._start_intensity = value

    @property
    def EndIntensity(self) -> int:
        """
        specifies the intensity at the end point of the gradient.
        """
        return self._end_intensity

    @EndIntensity.setter
    def EndIntensity(self, value: int) -> None:
        self._end_intensity = value

    @property
    def StepCount(self) -> int:
        """
        Specifies the number of steps of change color.
        
        What that means is undefined.
        """
        return self._step_count

    @StepCount.setter
    def StepCount(self, value: int) -> None:
        self._step_count = value


__all__ = ['Gradient']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.task
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .user_record import UserRecord as UserRecord_9a2e0ab9


class UrlRecord(object):
    """
    Struct Class


    See Also:
        `API UrlRecord <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1task_1_1UrlRecord.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.UrlRecord'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.task.UrlRecord'
    """Literal Constant ``com.sun.star.task.UrlRecord``"""

    def __init__(self, UserList: typing.Optional[typing.Tuple[UserRecord_9a2e0ab9, ...]] = (), Url: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            UserList (typing.Tuple[UserRecord, ...], optional): UserList value.
            Url (str, optional): Url value.
        """
        super().__init__()

        if isinstance(UserList, UrlRecord):
            oth: UrlRecord = UserList
            self.UserList = oth.UserList
            self.Url = oth.Url
            return

        kargs = {
            "UserList": UserList,
            "Url": Url,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._user_list = kwargs["UserList"]
        self._url = kwargs["Url"]


    @property
    def UserList(self) -> typing.Tuple[UserRecord_9a2e0ab9, ...]:
        return self._user_list

    @UserList.setter
    def UserList(self, value: typing.Tuple[UserRecord_9a2e0ab9, ...]) -> None:
        self._user_list = value

    @property
    def Url(self) -> str:
        """
        The URL for which these passwords where given.
        """
        return self._url

    @Url.setter
    def Url(self, value: str) -> None:
        self._url = value


__all__ = ['UrlRecord']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..util.date import Date as Date_60040844
    from ..util.date_time import DateTime as DateTime_84de09d3
    from ..util.time import Time as Time_604e0855

class XRowUpdate(XInterface_8f010a43):
    """
    is used to update data which is collected in a row.

    See Also:
        `API XRowUpdate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XRowUpdate.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XRowUpdate'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XRowUpdate'

    @abstractmethod
    def updateBinaryStream(self, columnIndex: int, x: XInputStream_98d40ab4, length: int) -> None:
        """
        updates a column with a stream value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateBoolean(self, columnIndex: int, x: bool) -> None:
        """
        updates a column with a boolean value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateByte(self, columnIndex: int, x: int) -> None:
        """
        updates a column with a byte value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateBytes(self, columnIndex: int, x: uno.ByteSequence) -> None:
        """
        updates a column with a byte array value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateCharacterStream(self, columnIndex: int, x: XInputStream_98d40ab4, length: int) -> None:
        """
        updates a column with a stream value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateDate(self, columnIndex: int, x: Date_60040844) -> None:
        """
        updates a column with a date value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateDouble(self, columnIndex: int, x: float) -> None:
        """
        updates a column with a double value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateFloat(self, columnIndex: int, x: float) -> None:
        """
        updates a column with a float value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateInt(self, columnIndex: int, x: int) -> None:
        """
        updates a column with an long value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateLong(self, columnIndex: int, x: int) -> None:
        """
        updates a column with a hyper value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateNull(self, columnIndex: int) -> None:
        """
        gives a nullable column a null value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateNumericObject(self, columnIndex: int, x: object, scale: int) -> None:
        """
        updates a column with an object value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateObject(self, columnIndex: int, x: object) -> None:
        """
        updates a column with an object value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateShort(self, columnIndex: int, x: int) -> None:
        """
        updates a column with a short value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateString(self, columnIndex: int, x: str) -> None:
        """
        updates a column with a string value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateTime(self, columnIndex: int, x: Time_604e0855) -> None:
        """
        updates a column with a time value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def updateTimestamp(self, columnIndex: int, x: DateTime_84de09d3) -> None:
        """
        updates a column with a timestamp value.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XRowUpdate']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.beans.get_direct_property_tolerant_result import GetDirectPropertyTolerantResult as GetDirectPropertyTolerantResult
with suppress(ImportError):
    from ...dyn.beans.get_property_tolerant_result import GetPropertyTolerantResult as GetPropertyTolerantResult
with suppress(ImportError):
    from ...dyn.beans.illegal_type_exception import IllegalTypeException as IllegalTypeException
with suppress(ImportError):
    from ...dyn.beans.introspection import Introspection as Introspection
with suppress(ImportError):
    from ...dyn.beans.introspection_exception import IntrospectionException as IntrospectionException
with suppress(ImportError):
    from ...dyn.beans.method_concept import MethodConcept as MethodConcept
with suppress(ImportError):
    from ...dyn.beans.method_concept import MethodConceptEnum as MethodConceptEnum
with suppress(ImportError):
    from ...dyn.beans.named_value import NamedValue as NamedValue
with suppress(ImportError):
    from ...dyn.beans.not_removeable_exception import NotRemoveableException as NotRemoveableException
with suppress(ImportError):
    from ...dyn.beans.property import Property as Property
with suppress(ImportError):
    from ...dyn.beans.property_attribute import PropertyAttribute as PropertyAttribute
with suppress(ImportError):
    from ...dyn.beans.property_attribute import PropertyAttributeEnum as PropertyAttributeEnum
with suppress(ImportError):
    from ...dyn.beans.property_bag import PropertyBag as PropertyBag
with suppress(ImportError):
    from ...dyn.beans.property_change_event import PropertyChangeEvent as PropertyChangeEvent
with suppress(ImportError):
    from ...dyn.beans.property_concept import PropertyConcept as PropertyConcept
with suppress(ImportError):
    from ...dyn.beans.property_concept import PropertyConceptEnum as PropertyConceptEnum
with suppress(ImportError):
    from ...dyn.beans.property_exist_exception import PropertyExistException as PropertyExistException
with suppress(ImportError):
    from ...dyn.beans.property_set import PropertySet as PropertySet
with suppress(ImportError):
    from ...dyn.beans.property_set_info_change import PropertySetInfoChange as PropertySetInfoChange
with suppress(ImportError):
    from ...dyn.beans.property_set_info_change import PropertySetInfoChangeEnum as PropertySetInfoChangeEnum
with suppress(ImportError):
    from ...dyn.beans.property_set_info_change_event import PropertySetInfoChangeEvent as PropertySetInfoChangeEvent
with suppress(ImportError):
    from ...dyn.beans.property_state import PropertyState as PropertyState
with suppress(ImportError):
    from ...dyn.beans.property_state_change_event import PropertyStateChangeEvent as PropertyStateChangeEvent
with suppress(ImportError):
    from ...dyn.beans.property_value import PropertyValue as PropertyValue
with suppress(ImportError):
    from ...dyn.beans.property_values import PropertyValues as PropertyValues
with suppress(ImportError):
    from ...dyn.beans.property_veto_exception import PropertyVetoException as PropertyVetoException
with suppress(ImportError):
    from ...dyn.beans.set_property_tolerant_failed import SetPropertyTolerantFailed as SetPropertyTolerantFailed
with suppress(ImportError):
    from ...dyn.beans.string_pair import StringPair as StringPair
with suppress(ImportError):
    from ...dyn.beans.tolerant_property_set_result_type import TolerantPropertySetResultType as TolerantPropertySetResultType
with suppress(ImportError):
    from ...dyn.beans.tolerant_property_set_result_type import TolerantPropertySetResultTypeEnum as TolerantPropertySetResultTypeEnum
with suppress(ImportError):
    from ...dyn.beans.unknown_property_exception import UnknownPropertyException as UnknownPropertyException
with suppress(ImportError):
    from ...dyn.beans.x_exact_name import XExactName as XExactName
with suppress(ImportError):
    from ...dyn.beans.x_fast_property_set import XFastPropertySet as XFastPropertySet
with suppress(ImportError):
    from ...dyn.beans.x_hierarchical_property_set import XHierarchicalPropertySet as XHierarchicalPropertySet
with suppress(ImportError):
    from ...dyn.beans.x_hierarchical_property_set_info import XHierarchicalPropertySetInfo as XHierarchicalPropertySetInfo
with suppress(ImportError):
    from ...dyn.beans.x_introspection import XIntrospection as XIntrospection
with suppress(ImportError):
    from ...dyn.beans.x_introspection_access import XIntrospectionAccess as XIntrospectionAccess
with suppress(ImportError):
    from ...dyn.beans.x_material_holder import XMaterialHolder as XMaterialHolder
with suppress(ImportError):
    from ...dyn.beans.x_multi_hierarchical_property_set import XMultiHierarchicalPropertySet as XMultiHierarchicalPropertySet
with suppress(ImportError):
    from ...dyn.beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet
with suppress(ImportError):
    from ...dyn.beans.x_multi_property_states import XMultiPropertyStates as XMultiPropertyStates
with suppress(ImportError):
    from ...dyn.beans.x_properties_change_listener import XPropertiesChangeListener as XPropertiesChangeListener
with suppress(ImportError):
    from ...dyn.beans.x_properties_change_notifier import XPropertiesChangeNotifier as XPropertiesChangeNotifier
with suppress(ImportError):
    from ...dyn.beans.x_property import XProperty as XProperty
with suppress(ImportError):
    from ...dyn.beans.x_property_access import XPropertyAccess as XPropertyAccess
with suppress(ImportError):
    from ...dyn.beans.x_property_bag import XPropertyBag as XPropertyBag
with suppress(ImportError):
    from ...dyn.beans.x_property_change_listener import XPropertyChangeListener as XPropertyChangeListener
with suppress(ImportError):
    from ...dyn.beans.x_property_container import XPropertyContainer as XPropertyContainer
with suppress(ImportError):
    from ...dyn.beans.x_property_set import XPropertySet as XPropertySet
with suppress(ImportError):
    from ...dyn.beans.x_property_set_info import XPropertySetInfo as XPropertySetInfo
with suppress(ImportError):
    from ...dyn.beans.x_property_set_info_change_listener import XPropertySetInfoChangeListener as XPropertySetInfoChangeListener
with suppress(ImportError):
    from ...dyn.beans.x_property_set_info_change_notifier import XPropertySetInfoChangeNotifier as XPropertySetInfoChangeNotifier
with suppress(ImportError):
    from ...dyn.beans.x_property_set_option import XPropertySetOption as XPropertySetOption
with suppress(ImportError):
    from ...dyn.beans.x_property_state import XPropertyState as XPropertyState
with suppress(ImportError):
    from ...dyn.beans.x_property_state_change_listener import XPropertyStateChangeListener as XPropertyStateChangeListener
with suppress(ImportError):
    from ...dyn.beans.x_property_with_state import XPropertyWithState as XPropertyWithState
with suppress(ImportError):
    from ...dyn.beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet
with suppress(ImportError):
    from ...dyn.beans.x_vetoable_change_listener import XVetoableChangeListener as XVetoableChangeListener
with suppress(ImportError):
    from ...dyn.beans.the_introspection import theIntrospection as theIntrospection



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation


class EffectNodeType(object):
    """
    Const Class

    This constants defines a type for an animation effect node.
    
    This is stored with the name node-type inside the com.sun.star.animations.XAnimationNode.UserData sequence. This does not manipulate the timing or synchronization. It can be used to quickly identify semantic blocks inside an animation hierarchy.

    See Also:
        `API EffectNodeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation_1_1EffectNodeType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.EffectNodeType'
    __ooo_type_name__: str = 'const'

    DEFAULT = 0
    """
    This node has no special meaning.
    """
    ON_CLICK = 1
    """
    This node contains an effect that starts on click.
    """
    WITH_PREVIOUS = 2
    """
    This node contains an effect that starts with a previous effect.
    """
    AFTER_PREVIOUS = 3
    """
    This node contains an effect that starts after a previous effect has finished.
    """
    MAIN_SEQUENCE = 4
    """
    This is the main sequence for effects that is automatically started.
    """
    TIMING_ROOT = 5
    """
    This is the root sequence.
    """
    INTERACTIVE_SEQUENCE = 6
    """
    This is a sequence with effects that starts due to user interaction.
    """

__all__ = ['EffectNodeType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..sdbc.result_set import ResultSet as ResultSet_8ecf0a4f
from ..sdbc.x_closeable import XCloseable as XCloseable_98290a86
from ..sdbc.x_result_set import XResultSet as XResultSet_98e30aa7
from ..sdbc.x_result_set_meta_data_supplier import XResultSetMetaDataSupplier as XResultSetMetaDataSupplier_777010fc
from ..sdbc.x_row import XRow as XRow_5f360834
from .x_content_access import XContentAccess as XContentAccess_ba220bc7

class ContentResultSet(ResultSet_8ecf0a4f, XPropertySet_bc180bfa, XComponent_98dc0ab5, XCloseable_98290a86, XResultSet_98e30aa7, XResultSetMetaDataSupplier_777010fc, XRow_5f360834, XContentAccess_ba220bc7):
    """
    Service Class

    provides access to the children of a folder content.
    
    It can be understand as a table containing a row for each child. The table columns may contain values of properties of the children.

    See Also:
        `API ContentResultSet <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1ContentResultSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.ContentResultSet'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CursorTravelMode(self) -> int:
        """
        controls the travel mode of the result set cursor.
        
        There are two possible travel modes:
        
        The following pseudo-code illustrates the usage of a non-blocking cursor:
        
        If this property is not supported, the implementation needs to provide a blocking cursor.
        
        The implementation initially needs to set the value of this property to CursorTravelMode.BLOCKING.
        """
        ...

    @abstractproperty
    def IsRowCountFinal(self) -> bool:
        """
        indicates that all rows of the result set have been obtained.
        """
        ...

    @abstractproperty
    def RowCount(self) -> int:
        """
        contains the number of rows obtained (so far) from the data source.
        """
        ...


__all__ = ['ContentResultSet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.container.container_event import ContainerEvent as ContainerEvent
from ...lo.container.element_exist_exception import ElementExistException as ElementExistException
from ...lo.container.enumerable_map import EnumerableMap as EnumerableMap
from ...lo.container.no_such_element_exception import NoSuchElementException as NoSuchElementException
from ...lo.container.x_child import XChild as XChild
from ...lo.container.x_component_enumeration import XComponentEnumeration as XComponentEnumeration
from ...lo.container.x_component_enumeration_access import XComponentEnumerationAccess as XComponentEnumerationAccess
from ...lo.container.x_container import XContainer as XContainer
from ...lo.container.x_container_approve_broadcaster import XContainerApproveBroadcaster as XContainerApproveBroadcaster
from ...lo.container.x_container_approve_listener import XContainerApproveListener as XContainerApproveListener
from ...lo.container.x_container_listener import XContainerListener as XContainerListener
from ...lo.container.x_container_query import XContainerQuery as XContainerQuery
from ...lo.container.x_content_enumeration_access import XContentEnumerationAccess as XContentEnumerationAccess
from ...lo.container.x_element_access import XElementAccess as XElementAccess
from ...lo.container.x_enumerable_map import XEnumerableMap as XEnumerableMap
from ...lo.container.x_enumeration import XEnumeration as XEnumeration
from ...lo.container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess
from ...lo.container.x_hierarchical_name import XHierarchicalName as XHierarchicalName
from ...lo.container.x_hierarchical_name_access import XHierarchicalNameAccess as XHierarchicalNameAccess
from ...lo.container.x_hierarchical_name_container import XHierarchicalNameContainer as XHierarchicalNameContainer
from ...lo.container.x_hierarchical_name_replace import XHierarchicalNameReplace as XHierarchicalNameReplace
from ...lo.container.x_identifier_access import XIdentifierAccess as XIdentifierAccess
from ...lo.container.x_identifier_container import XIdentifierContainer as XIdentifierContainer
from ...lo.container.x_identifier_replace import XIdentifierReplace as XIdentifierReplace
from ...lo.container.x_implicit_id_access import XImplicitIDAccess as XImplicitIDAccess
from ...lo.container.x_implicit_id_container import XImplicitIDContainer as XImplicitIDContainer
from ...lo.container.x_implicit_id_replace import XImplicitIDReplace as XImplicitIDReplace
from ...lo.container.x_index_access import XIndexAccess as XIndexAccess
from ...lo.container.x_index_container import XIndexContainer as XIndexContainer
from ...lo.container.x_index_replace import XIndexReplace as XIndexReplace
from ...lo.container.x_map import XMap as XMap
from ...lo.container.x_name_access import XNameAccess as XNameAccess
from ...lo.container.x_name_container import XNameContainer as XNameContainer
from ...lo.container.x_name_replace import XNameReplace as XNameReplace
from ...lo.container.x_named import XNamed as XNamed
from ...lo.container.x_set import XSet as XSet
from ...lo.container.x_string_key_map import XStringKeyMap as XStringKeyMap
from ...lo.container.x_unique_id_access import XUniqueIDAccess as XUniqueIDAccess



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ExternalLinkType(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.ExternalLinkType", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.ExternalLinkType``"""
        pass

    class ExternalLinkTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.ExternalLinkType", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.ExternalLinkType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sheet import ExternalLinkType as ExternalLinkType
    else:
        # keep document generators happy
        from ...lo.sheet.external_link_type import ExternalLinkType as ExternalLinkType

    class ExternalLinkTypeEnum(IntEnum):
        """
        Enum of Const Class ExternalLinkType

        Constants designating the link type in ExternalLinkInfo, used with FormulaParser.ExternalLinks.
        
        **since**
        
            OOo 3.1
        """
        UNKNOWN = ExternalLinkType.UNKNOWN
        """
        Unknown element type.
        """
        DOCUMENT = ExternalLinkType.DOCUMENT
        """
        URL of an external document.
        """
        DDE = ExternalLinkType.DDE
        """
        DDE link.
        """
        SELF = ExternalLinkType.SELF
        """
        Reference to the own document.
        """
        SPECIAL = ExternalLinkType.SPECIAL
        """
        For special use cases.
        
        Behaviour is dependent on the implementation of the formula parser.
        """

__all__ = ['ExternalLinkType', 'ExternalLinkTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.registry
from __future__ import annotations
from .x_simple_registry import XSimpleRegistry as XSimpleRegistry_10150e9c

class DefaultRegistry(XSimpleRegistry_10150e9c):
    """
    Service Class

    implicitly supports a local registry and a read-only system registry for global information.
    
    In the context of this service, the functions open, close, and destroy from XSimpleRegistry are not supported and throw an exception if they are used.
    
    Functions of XSimpleRegistry:
    
    Functions of XRegistryKey:
    
    How to find the registries:

    See Also:
        `API DefaultRegistry <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1registry_1_1DefaultRegistry.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.registry'
    __ooo_full_ns__: str = 'com.sun.star.registry.DefaultRegistry'
    __ooo_type_name__: str = 'service'


__all__ = ['DefaultRegistry']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.uno
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class TypeClass(Enum):
    """
    Enum Class


    See Also:
        `API TypeClass <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328>`_
    """
    __ooo_ns__: str = "com.sun.star.uno"
    __ooo_full_ns__: str = "com.sun.star.uno.TypeClass"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.uno.TypeClass"

    ANY = "ANY"
    """
    reflecting the any type; anys can carry any UNO value except of any values
    """
    ARRAY = "ARRAY"
    """
    Deprecated, UNOIDL does not have an array concept.
    """
    BOOLEAN = "BOOLEAN"
    """
    reflecting the boolean type; true and false
    """
    BYTE = "BYTE"
    """
    reflecting the 8-bit ordinal type
    """
    CHAR = "CHAR"
    """
    reflecting the 16-bit unicode character type
    """
    CONSTANT = "CONSTANT"
    """
    reflecting constants
    """
    CONSTANTS = "CONSTANTS"
    """
    reflecting constants groups
    """
    DOUBLE = "DOUBLE"
    """
    reflecting the 64-bit floating point type
    """
    ENUM = "ENUM"
    """
    reflecting enum types
    """
    EXCEPTION = "EXCEPTION"
    """
    reflecting exception types
    """
    FLOAT = "FLOAT"
    """
    reflecting the 32-bit floating point type
    """
    HYPER = "HYPER"
    """
    reflecting the signed 64-bit ordinal type
    """
    INTERFACE = "INTERFACE"
    """
    reflecting interface types
    """
    INTERFACE_ATTRIBUTE = "INTERFACE_ATTRIBUTE"
    """
    reflecting interface attributes
    """
    INTERFACE_METHOD = "INTERFACE_METHOD"
    """
    reflecting interface methods
    """
    LONG = "LONG"
    """
    reflecting the signed 32-bit ordinal type
    """
    MODULE = "MODULE"
    """
    reflecting modules
    """
    PROPERTY = "PROPERTY"
    """
    reflecting properties
    """
    SEQUENCE = "SEQUENCE"
    """
    reflecting sequence types
    """
    SERVICE = "SERVICE"
    """
    reflecting services
    """
    SHORT = "SHORT"
    """
    reflecting the signed 16-bit ordinal type
    """
    SINGLETON = "SINGLETON"
    """
    reflecting singletons
    """
    STRING = "STRING"
    """
    reflecting the string type; strings of unicode characters
    """
    STRUCT = "STRUCT"
    """
    reflecting compound types
    """
    TYPE = "TYPE"
    """
    reflecting the meta type
    """
    TYPEDEF = "TYPEDEF"
    """
    reflecting typedefed types referencing other types
    """
    UNION = "UNION"
    """
    Deprecated, UNOIDL does not have a union concept.
    """
    UNKNOWN = "UNKNOWN"
    """
    reflecting the unreflectable type
    """
    UNSIGNED_HYPER = "UNSIGNED_HYPER"
    """
    reflecting the unsigned 64-bit ordinal type
    """
    UNSIGNED_LONG = "UNSIGNED_LONG"
    """
    reflecting the unsigned 32-bit type
    """
    UNSIGNED_SHORT = "UNSIGNED_SHORT"
    """
    reflecting the unsigned 16-bit ordinal type
    """
    VOID = "VOID"
    """
    reflecting the void type; denotes no type
    """

__all__ = ["TypeClass"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs


class ExtendedFilePickerElementIds(object):
    """
    Const Class

    These constants are used to specify extended controls of a FilePicker dialog. A FilePicker service may be initialized so that it has additional controls extending the set of common controls a FilePicker usually supports.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API ExtendedFilePickerElementIds <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ExtendedFilePickerElementIds.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.ExtendedFilePickerElementIds'
    __ooo_type_name__: str = 'const'

    CHECKBOX_AUTOEXTENSION = 100
    CHECKBOX_PASSWORD = 101
    CHECKBOX_FILTEROPTIONS = 102
    CHECKBOX_READONLY = 103
    CHECKBOX_LINK = 104
    CHECKBOX_PREVIEW = 105
    PUSHBUTTON_PLAY = 106
    LISTBOX_VERSION = 107
    LISTBOX_TEMPLATE = 108
    LISTBOX_IMAGE_TEMPLATE = 109
    CHECKBOX_SELECTION = 110
    LISTBOX_VERSION_LABEL = 207
    LISTBOX_TEMPLATE_LABEL = 208
    LISTBOX_IMAGE_TEMPLATE_LABEL = 209
    LISTBOX_FILTER_SELECTOR = 210
    CHECKBOX_GPGENCRYPTION = 211
    LISTBOX_IMAGE_ANCHOR = 212
    LISTBOX_IMAGE_ANCHOR_LABEL = 213

__all__ = ['ExtendedFilePickerElementIds']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Time(object):
    """
    Struct Class

    represents a time value.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API Time <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1Time.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.Time'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.util.Time'
    """Literal Constant ``com.sun.star.util.Time``"""

    def __init__(self, NanoSeconds: typing.Optional[int] = 0, Seconds: typing.Optional[int] = 0, Minutes: typing.Optional[int] = 0, Hours: typing.Optional[int] = 0, IsUTC: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            NanoSeconds (int, optional): NanoSeconds value.
            Seconds (int, optional): Seconds value.
            Minutes (int, optional): Minutes value.
            Hours (int, optional): Hours value.
            IsUTC (bool, optional): IsUTC value.
        """
        super().__init__()

        if isinstance(NanoSeconds, Time):
            oth: Time = NanoSeconds
            self.NanoSeconds = oth.NanoSeconds
            self.Seconds = oth.Seconds
            self.Minutes = oth.Minutes
            self.Hours = oth.Hours
            self.IsUTC = oth.IsUTC
            return

        kargs = {
            "NanoSeconds": NanoSeconds,
            "Seconds": Seconds,
            "Minutes": Minutes,
            "Hours": Hours,
            "IsUTC": IsUTC,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._nano_seconds = kwargs["NanoSeconds"]
        self._seconds = kwargs["Seconds"]
        self._minutes = kwargs["Minutes"]
        self._hours = kwargs["Hours"]
        self._is_utc = kwargs["IsUTC"]


    @property
    def NanoSeconds(self) -> int:
        """
        contains the nanoseconds (0 - 999 999 999).
        """
        return self._nano_seconds

    @NanoSeconds.setter
    def NanoSeconds(self, value: int) -> None:
        self._nano_seconds = value

    @property
    def Seconds(self) -> int:
        """
        contains the seconds (0-59).
        """
        return self._seconds

    @Seconds.setter
    def Seconds(self, value: int) -> None:
        self._seconds = value

    @property
    def Minutes(self) -> int:
        """
        contains the minutes (0-59).
        """
        return self._minutes

    @Minutes.setter
    def Minutes(self, value: int) -> None:
        self._minutes = value

    @property
    def Hours(self) -> int:
        """
        contains the hour (0-23).
        """
        return self._hours

    @Hours.setter
    def Hours(self, value: int) -> None:
        self._hours = value

    @property
    def IsUTC(self) -> bool:
        """
        true: time zone is UTC false: unknown time zone.
        
        **since**
        
            LibreOffice 4.1
        """
        return self._is_utc

    @IsUTC.setter
    def IsUTC(self, value: bool) -> None:
        self._is_utc = value


__all__ = ['Time']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from .x_report_component import XReportComponent as XReportComponent_df0e2b
from .x_report_control_format import XReportControlFormat as XReportControlFormat_3d4e0fc2
if typing.TYPE_CHECKING:
    from .x_format_condition import XFormatCondition as XFormatCondition_ffb00e0c

class XReportControlModel(XContainer_d6fb0cc6, XIndexContainer_1c040ebe, XReportComponent_df0e2b, XReportControlFormat_3d4e0fc2):
    """

    See Also:
        `API XReportControlModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XReportControlModel'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XReportControlModel'

    @abstractmethod
    def createFormatCondition(self) -> XFormatCondition_ffb00e0c:
        """
        Creates a format condition.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractproperty
    def ConditionalPrintExpression(self) -> str:
        """
        Describes the print expression of the report control model.
        
        If the expression evaluates to true than the report control model will be printed otherwise not.
        """
        ...

    @abstractproperty
    def DataField(self) -> str:
        """
        Specifies which content should be shown.
        
        The value can be
        """
        ...

    @abstractproperty
    def PrintWhenGroupChange(self) -> bool:
        """
        Specifies that the element gets printed when the group changes.
        
        The default value is TRUE.
        """
        ...


__all__ = ['XReportControlModel']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .calendar import Calendar as Calendar_7f2d0962
    from .calendar_item import CalendarItem as CalendarItem_a86c0af1
    from ..lang.locale import Locale as Locale_70d308fa

class XCalendar(XInterface_8f010a43):
    """
    Access to locale specific calendar systems.
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API XCalendar <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XCalendar.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XCalendar'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XCalendar'

    @abstractmethod
    def addValue(self, nCalendarFieldIndex: int, nAmount: int) -> None:
        """
        Add an amount to a field.
        """
        ...
    @abstractmethod
    def getAllCalendars(self, rLocale: Locale_70d308fa) -> typing.Tuple[str, ...]:
        """
        Returns all available calendars for the given locale.
        """
        ...
    @abstractmethod
    def getDateTime(self) -> float:
        """
        Get the UTC date/time as an offset to the start of the calendar at 1-Jan-1970 00:00.
        
        The integer part represents the number of days passed since start date. The fractional part represents fractions of a day, thus 0.5 means 12 hours.
        """
        ...
    @abstractmethod
    def getDays(self) -> typing.Tuple[CalendarItem_a86c0af1, ...]:
        """
        returns a sequence of CalendarItem describing the day names.
        """
        ...
    @abstractmethod
    def getDisplayName(self, nCalendarDisplayIndex: int, nIdx: int, nNameType: int) -> str:
        """
        Returns a string (name to display) matching the given parameters.
        
        The value should be obtained by a previous call to XCalendar.getValue() with an appropriate CalendarFieldIndex argument.
        
        This parameter is not used if the nCalendarDisplayIndex argument equals CalendarDisplayIndex.AM_PM
        
        **since**
        
            LibreOffice 3.5
        """
        ...
    @abstractmethod
    def getFirstDayOfWeek(self) -> int:
        """
        returns the first day of a week, one of Weekdays values.
        """
        ...
    @abstractmethod
    def getLoadedCalendar(self) -> Calendar_7f2d0962:
        """
        Get the currently loaded Calendar.
        """
        ...
    @abstractmethod
    def getMinimumNumberOfDaysForFirstWeek(self) -> int:
        """
        returns how many days of a week must reside in the first week of a year.
        """
        ...
    @abstractmethod
    def getMonths(self) -> typing.Tuple[CalendarItem_a86c0af1, ...]:
        """
        returns a sequence of CalendarItem describing the month names.
        """
        ...
    @abstractmethod
    def getNumberOfDaysInWeek(self) -> int:
        """
        returns the number of days in a week, e.g. 7
        """
        ...
    @abstractmethod
    def getNumberOfMonthsInYear(self) -> int:
        """
        returns the number of months in a year, e.g. 12
        """
        ...
    @abstractmethod
    def getUniqueID(self) -> str:
        """
        Returns the ID string of the loaded calendar, for example, \"Gregorian\"
        """
        ...
    @abstractmethod
    def getValue(self, nCalendarFieldIndex: int) -> int:
        """
        Get the value of a field.
        """
        ...
    @abstractmethod
    def isValid(self) -> bool:
        """
        Verify if the date fields set by a combination of XCalendar.setValue() calls is valid.
        
        It has a side-effect because it will internally calculate the final value for the date fields
        """
        ...
    @abstractmethod
    def loadCalendar(self, uniqueID: str, rLocale: Locale_70d308fa) -> None:
        """
        Load a specific calendar for the given locale.
        """
        ...
    @abstractmethod
    def loadDefaultCalendar(self, rLocale: Locale_70d308fa) -> None:
        """
        Load the default calendar for the given locale.
        """
        ...
    @abstractmethod
    def setDateTime(self, nTimeInDays: float) -> None:
        """
        Set the UTC date/time as an offset to the start of the calendar at 1-Jan-1970 00:00.
        
        The integer part represents the number of days passed since start date. The fractional part represents fractions of a day, thus 0.5 means 12 hours.
        """
        ...
    @abstractmethod
    def setFirstDayOfWeek(self, nDay: int) -> None:
        """
        Set the first day of a week, one of Weekdays values.
        """
        ...
    @abstractmethod
    def setMinimumNumberOfDaysForFirstWeek(self, nDays: int) -> None:
        """
        Set how many days of a week must reside in the first week of a year.
        """
        ...
    @abstractmethod
    def setValue(self, nCalendarFieldIndex: int, nValue: int) -> None:
        """
        Set the value of a field.
        """
        ...

__all__ = ['XCalendar']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from .gradient import Gradient as Gradient_7a8a0982
    from .simple_font_metric import SimpleFontMetric as SimpleFontMetric_d53c0cb9
    from .x_device import XDevice as XDevice_70ba08fc
    from .x_display_bitmap import XDisplayBitmap as XDisplayBitmap_bb550bdf
    from .x_font import XFont as XFont_5f480843
    from .x_region import XRegion as XRegion_70f30910
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.awt.RasterOperation import RasterOperationProto  # type: ignore

class XGraphics(XInterface_8f010a43):
    """
    provides the basic output operation of a device.

    See Also:
        `API XGraphics <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XGraphics'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XGraphics'

    @abstractmethod
    def copy(self, xSource: XDevice_70ba08fc, nSourceX: int, nSourceY: int, nSourceWidth: int, nSourceHeight: int, nDestX: int, nDestY: int, nDestWidth: int, nDestHeight: int) -> None:
        """
        copies a rectangle of pixels from another device into this one.
        """
        ...
    @abstractmethod
    def draw(self, xBitmapHandle: XDisplayBitmap_bb550bdf, SourceX: int, SourceY: int, SourceWidth: int, SourceHeight: int, DestX: int, DestY: int, DestWidth: int, DestHeight: int) -> None:
        """
        draws a part of the specified bitmap to the output device.
        """
        ...
    @abstractmethod
    def drawArc(self, X: int, Y: int, Width: int, Height: int, X1: int, Y1: int, X2: int, Y2: int) -> None:
        """
        draws an arc (part of a circle) in the output device.
        """
        ...
    @abstractmethod
    def drawChord(self, nX: int, nY: int, nWidth: int, nHeight: int, nX1: int, nY1: int, nX2: int, nY2: int) -> None:
        """
        draws a chord of a circular area in the output device.
        
        A chord is a segment of a circle. You get two chords from a circle if you intersect the circle with a straight line joining two points on the circle.
        """
        ...
    @abstractmethod
    def drawEllipse(self, X: int, Y: int, Width: int, Height: int) -> None:
        """
        draws an ellipse in the output device.
        """
        ...
    @abstractmethod
    def drawGradient(self, nX: int, nY: int, nWidth: int, Height: int, aGradient: Gradient_7a8a0982) -> None:
        """
        draws a color dispersion in the output device.
        """
        ...
    @abstractmethod
    def drawLine(self, X1: int, Y1: int, X2: int, Y2: int) -> None:
        """
        draws a line in the output device.
        """
        ...
    @abstractmethod
    def drawPie(self, X: int, Y: int, Width: int, Height: int, X1: int, Y1: int, X2: int, Y2: int) -> None:
        """
        draws a circular area in the output device.
        """
        ...
    @abstractmethod
    def drawPixel(self, X: int, Y: int) -> None:
        """
        sets a single pixel in the output device.
        """
        ...
    @abstractmethod
    def drawPolyLine(self, DataX: uno.ByteSequence, DataY: uno.ByteSequence) -> None:
        """
        draws multiple lines in the output device at once.
        """
        ...
    @abstractmethod
    def drawPolyPolygon(self, DataX: typing.Tuple[uno.ByteSequence, ...], DataY: typing.Tuple[uno.ByteSequence, ...]) -> None:
        """
        draws multiple polygons in the output device at once.
        """
        ...
    @abstractmethod
    def drawPolygon(self, DataX: uno.ByteSequence, DataY: uno.ByteSequence) -> None:
        """
        draws a polygon line in the output device.
        """
        ...
    @abstractmethod
    def drawRect(self, X: int, Y: int, Width: int, Height: int) -> None:
        """
        draws a rectangle in the output device.
        """
        ...
    @abstractmethod
    def drawRoundedRect(self, X: int, Y: int, Width: int, Height: int, nHorzRound: int, nVertRound: int) -> None:
        """
        draws a rectangle with rounded corners in the output device.
        """
        ...
    @abstractmethod
    def drawText(self, X: int, Y: int, Text: str) -> None:
        """
        draws text in the output device.
        """
        ...
    @abstractmethod
    def drawTextArray(self, X: int, Y: int, Text: str, Longs: uno.ByteSequence) -> None:
        """
        draws texts in the output device using an explicit kerning table.
        """
        ...
    @abstractmethod
    def getDevice(self) -> XDevice_70ba08fc:
        """
        returns the device of this graphics.
        """
        ...
    @abstractmethod
    def getFontMetric(self) -> SimpleFontMetric_d53c0cb9:
        """
        returns the font metric of the current font.
        """
        ...
    @abstractmethod
    def intersectClipRegion(self, xClipping: XRegion_70f30910) -> None:
        """
        builds the intersection with the current region.
        """
        ...
    @abstractmethod
    def pop(self) -> None:
        """
        restores all previous saved settings.
        """
        ...
    @abstractmethod
    def push(self) -> None:
        """
        saves all current settings (Font, TextColor, TextFillColor, LineColor, FillColor, RasterOp, ClipRegion).
        """
        ...
    @abstractmethod
    def selectFont(self, aDescription: FontDescriptor_bc110c0a) -> None:
        """
        creates a new font and sets the font.
        """
        ...
    @abstractmethod
    def setClipRegion(self, Clipping: XRegion_70f30910) -> None:
        """
        sets the clip region to specified clipping.
        """
        ...
    @abstractmethod
    def setFillColor(self, nColor: Color_68e908c5) -> None:
        """
        sets the fill color.
        """
        ...
    @abstractmethod
    def setFont(self, xNewFont: XFont_5f480843) -> None:
        """
        sets the font used by text operations.
        """
        ...
    @abstractmethod
    def setLineColor(self, nColor: Color_68e908c5) -> None:
        """
        sets the line color.
        """
        ...
    @abstractmethod
    def setRasterOp(self, ROP: RasterOperationProto) -> None:
        """
        sets the raster operation.
        
        If the device does not support raster operations then this call is ignored.
        """
        ...
    @abstractmethod
    def setTextColor(self, nColor: Color_68e908c5) -> None:
        """
        sets the text color used by text operations.
        """
        ...
    @abstractmethod
    def setTextFillColor(self, nColor: Color_68e908c5) -> None:
        """
        sets the fill color used by text operations.
        """
        ...

__all__ = ['XGraphics']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c
    from ..sdbc.x_result_set import XResultSet as XResultSet_98e30aa7

class DataAccessDescriptor(ABC):
    """
    Service Class

    descriptor for accessing basic data access objects.
    
    Various components interacting with the database access world require to specify (or provide themselves) an object such as a query, a table, a result set, a connection to a data source, a column within a table, and so on.All of these objects are usually not specified with a single property, but with a set of properties, and for various objects, various (but not always different) properties are needed.The DataAccessDescriptor describes the super set of the properties for the most common data access objects.
    
    Every component providing or requiring a DataAccessDescriptor for some functionality is urged to specify which properties are mandatory, and which ones optional. Additionally, it's free to specify any additional requirements about the relations of properties.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DataAccessDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DataAccessDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DataAccessDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ConnectionInfo(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        specifies additional info to use when creating a connection from a ConnectionResource
        
        This member is evaluated only when ConnectionResource is used: In this case, com.sun.star.sdbc.XDriverManager.getConnectionWithInfo() is used to create a connection for the given connection resource, instead of com.sun.star.sdbc.XDriverManager.getConnection().
        
        If the sequence is empty, it is ignored.
        """
        ...

    @abstractproperty
    def Selection(self) -> typing.Tuple[object, ...]:
        """
        specifies a selection to confine the records in a result set.
        
        When you specify a result set either implicitly (DataSourceName, Command, CommandType) or explicitly (ResultSet), the set of results can be additionally refined with this property.
        
        The single elements of the Selection are either record numbers (see com.sun.star.sdbc.XResultSet.getRow()), or bookmarks (see com.sun.star.sdbcx.XRowLocate.getBookmark()).It is up to the component which provides or requires a DataAccessDescriptor to specify which of the two alternatives it expects. If it does not specify this, then the property BookmarkSelection becomes mandatory.
        
        If the elements specify bookmarks, and a ResultSet has been specified, then this result set is required to support the com.sun.star.sdbcx.XRowLocate interface.
        """
        ...

    @abstractproperty
    def ActiveConnection(self) -> XConnection_a36a0b0c:
        """
        is a connection to use.
        
        This object is guaranteed to be a com.sun.star.sdbc.Connection, but usually it will be a Connection from the module com.sun.star.sdb.Especially in the case where no DataSourceName is given, but CommandType is CommandType.QUERY, the ActiveConnection needs to fully support the Connection service, to actually retrieve the query specified by Command
        
        If no ActiveConnection is given, then a DataSourceName is required.
        """
        ...

    @abstractproperty
    def BookmarkSelection(self) -> bool:
        """
        specifies how to interpret Selection
        
        If present, BookmarkSelection specifies the semantics of Selection. If not present, it's up to the implementing component to specify this semantics.
        
        If TRUE, then the single elements of the array specified by Selection are bookmarks relative to the result set, if FALSE, they're record numbers.
        """
        ...

    @abstractproperty
    def Column(self) -> XPropertySet_bc180bfa:
        """
        specifies a column object
        
        For reasons of performance and saving resources, a supplier of an DataAccessDescriptor which is used to describe a column object can pass this object directly, instead of specifying it only implicitly with the ColumnName property.
        
        The object will at least support the com.sun.star.sdbcx.Column service, but more often it will even be a Column from the com.sun.star.sdb module.
        """
        ...

    @abstractproperty
    def ColumnName(self) -> str:
        """
        specifies a column name.
        
        This property is usually used together with the Command and CommandType properties.
        """
        ...

    @abstractproperty
    def Command(self) -> str:
        """
        specifies the command to execute to retrieve a result set.
        
        This property is only meaningful together with the CommandType property, thus either both or none of them are present.
        """
        ...

    @abstractproperty
    def CommandType(self) -> int:
        """
        specifies the type of the command to be executed to retrieve a result set.
        
        Command needs to be interpreted depending on the value of this property.
        
        This property is only meaningful together with the Command property, thus either both or none of them are present.
        """
        ...

    @abstractproperty
    def ConnectionResource(self) -> str:
        """
        specifies the database URL which locates a database driver.
        
        This database URL is usually used to create a Connection. If no ConnectionResource is given, then an ActiveConnection is required.
        """
        ...

    @abstractproperty
    def DataSourceName(self) -> str:
        """
        specifies the name of the datasource to access.
        
        This data source is usually used to create a Connection. If no DataSourceName is given and the DatabaseLocation and the ConnectionResource are empty, then an ActiveConnection is required.
        """
        ...

    @abstractproperty
    def DatabaseLocation(self) -> str:
        """
        specifies the URL of the database file.
        
        This database location is usually used to create a Connection. If no DatabaseLocation is given and the ConnectionResource is empty, then an ActiveConnection is required.
        """
        ...

    @abstractproperty
    def EscapeProcessing(self) -> bool:
        """
        specifies if the Command should be analyzed on the client side before sending it to the database server.
        
        The default value of this property is TRUE. By switching it to FALSE, you can pass backend-specific SQL statements, which are not standard SQL, to your database.
        
        This property is usually present together with the Command and CommandType properties, and is evaluated if and only if CommandType equals CommandType.COMMAND.
        """
        ...

    @abstractproperty
    def Filter(self) -> str:
        """
        specifies an additional filter to optionally use.
        
        The Filter string has to form a WHERE-clause, without the WHERE-string itself.
        
        If a DataSourceName, Command and CommandType are specified, a RowSet can be created with this information. If the results provided by the row set are to be additionally filtered, the Filter property can be used.
        
        Note that the Filter property does not make sense if a ResultSet has been specified in the DataAccessDescriptor.
        """
        ...

    @abstractproperty
    def GroupBy(self) -> str:
        """
        specifies an additional GROUP BY clause which should be applied on top of the given Command.
        
        The keyword GROUP BY itself is not part of this property.
        """
        ...

    @abstractproperty
    def HavingClause(self) -> str:
        """
        specifies an additional HAVING clause which should be applied on top of the given Command.
        
        The keyword HAVING itself is not part of this property.
        """
        ...

    @abstractproperty
    def Order(self) -> str:
        """
        specifies an additional ORDER BY clause which should be applied on top of the given Command.
        
        The keyword ORDER BY itself is not part of this property.
        """
        ...

    @abstractproperty
    def ResultSet(self) -> XResultSet_98e30aa7:
        """
        specifies an already existent result set to use.
        
        Usually, you use the properties DataSourceName (alternatively ActiveConnection), Command and CommandType to specify how to obtain a result set. However, in scenarios where the provider of a DataAccessDescriptor has access to an already existent result set, it can pass it along for reusage. This is encouraged to increase performance.
        
        The object will at least support the com.sun.star.sdbc.ResultSet service.
        
        Note that any superservices of com.sun.star.sdbc.ResultSet are also allowed. Especially, this member can denote an instance of the com.sun.star.sdb.RowSet, or an instance obtained by calling com.sun.star.sdb.XResultSetAccess.createResultSet() on such a com.sun.star.sdb.RowSet. This becomes important in conjunction with the Selection property.
        """
        ...


__all__ = ['DataAccessDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from .x_bitmap import XBitmap as XBitmap_b1b70b7b
if typing.TYPE_CHECKING:
    from ..geometry.integer_point2_d import IntegerPoint2D as IntegerPoint2D_8f0dc2
    from ..geometry.integer_rectangle2_d import IntegerRectangle2D as IntegerRectangle2D_3c5c0f4d
    from .floating_point_bitmap_layout import FloatingPointBitmapLayout as FloatingPointBitmapLayout_c66812df

class XHalfFloatReadOnlyBitmap(XBitmap_b1b70b7b):
    """
    Specialized interface for bitmaps containing half floats as their color components.
    
    Half floats are 16 bit wide, and some high-end GPUs already have them as supported frame buffer format. In contrast to XHalfFloatBitmap, this interface only permits read-only access.
    
    Use this interface for e.g. bitmaps that are calculated on-the-fly, or that are pure functional, and thus cannot be modified.
    
    If you get passed an instance of XHalfFloatReadOnlyBitmap that also supports the XVolatileBitmap interface, things become a bit more complicated. When reading data, one has to check for both VolatileContentDestroyedException and mismatching FloatingPointBitmapLayout return values. If either of them occurs, the whole bitmap read operation should be repeated.

    See Also:
        `API XHalfFloatReadOnlyBitmap <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XHalfFloatReadOnlyBitmap.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XHalfFloatReadOnlyBitmap'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XHalfFloatReadOnlyBitmap'

    @abstractmethod
    def getData(self, rect: IntegerRectangle2D_3c5c0f4d) -> uno.ByteSequence:
        """
        Query the raw data of this bitmap.
        
        Query the raw data of this bitmap, in the format as defined by getMemoryLayout(). With the given rectangle, a subset of the whole bitmap can be queried. When querying subsets of the bitmap, the same scanline padding takes place as when the whole bitmap is requested. Note: as we currently have no 16 bit float UNO data type, the values are transported as 16 bit integers across the API (which requires casting on both sides).

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...
    @abstractmethod
    def getMemoryLayout(self) -> FloatingPointBitmapLayout_c66812df:
        """
        Query the memory layout for this bitmap.
        """
        ...
    @abstractmethod
    def getPixel(self, pos: IntegerPoint2D_8f0dc2) -> uno.ByteSequence:
        """
        Get a single pixel of the bitmap, returning its color value.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...

__all__ = ['XHalfFloatReadOnlyBitmap']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdbc
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
import uno
from .sql_exception import SQLException as SQLException_acc90b43
from ..uno.x_interface import XInterface as XInterface_8f010a43

class BatchUpdateException(SQLException_acc90b43):
    """
    Exception Class

    is thrown when an error occurs during a batch update operation.
    
    In addition to the information provided by com.sun.star.sdbc.SQLException , a BatchUpdateException provides the update counts for all commands that were executed successfully during the batch update, that is, all commands that were executed before the error occurred. The order of elements in an array of update counts corresponds to the order in which commands were added to the batch.

    See Also:
        `API BatchUpdateException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.BatchUpdateException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.sdbc.BatchUpdateException'
    __pyunostruct__: str = 'com.sun.star.sdbc.BatchUpdateException'

    typeName: str = 'com.sun.star.sdbc.BatchUpdateException'
    """Literal Constant ``com.sun.star.sdbc.BatchUpdateException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, SQLState: typing.Optional[str] = '', ErrorCode: typing.Optional[int] = 0, NextException: typing.Optional[object] = None, UpdateCounts: typing.Optional[uno.ByteSequence] = ()) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            SQLState (str, optional): SQLState value.
            ErrorCode (int, optional): ErrorCode value.
            NextException (object, optional): NextException value.
            UpdateCounts (uno.ByteSequence, optional): UpdateCounts value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "SQLState": SQLState,
            "ErrorCode": ErrorCode,
            "NextException": NextException,
            "UpdateCounts": UpdateCounts,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._update_counts = kwargs["UpdateCounts"]
        inst_keys = ('UpdateCounts',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def UpdateCounts(self) -> uno.ByteSequence:
        """
        is an array of long , with each element indicating the update count for a SQL command that executed successfully before the exception was thrown.
        """
        return self._update_counts
    
    @UpdateCounts.setter
    def UpdateCounts(self, value: uno.ByteSequence) -> None:
        self._update_counts = value


__all__ = ['BatchUpdateException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .search_criterium import SearchCriterium as SearchCriterium_c6d30c4c
from .search_recursion import SearchRecursion as SearchRecursion_c7080c52


class SearchInfo(object):
    """
    Struct Class

    information needed to (recursively) search an object.

    See Also:
        `API SearchInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1SearchInfo.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.SearchInfo'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.SearchInfo'
    """Literal Constant ``com.sun.star.ucb.SearchInfo``"""

    def __init__(self, Criteria: typing.Optional[typing.Tuple[SearchCriterium_c6d30c4c, ...]] = (), Recursion: typing.Optional[SearchRecursion_c7080c52] = SearchRecursion_c7080c52.NONE, IncludeBase: typing.Optional[bool] = False, RespectFolderViewRestrictions: typing.Optional[bool] = False, RespectDocViewRestrictions: typing.Optional[bool] = False, FollowIndirections: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Criteria (typing.Tuple[SearchCriterium, ...], optional): Criteria value.
            Recursion (SearchRecursion, optional): Recursion value.
            IncludeBase (bool, optional): IncludeBase value.
            RespectFolderViewRestrictions (bool, optional): RespectFolderViewRestrictions value.
            RespectDocViewRestrictions (bool, optional): RespectDocViewRestrictions value.
            FollowIndirections (bool, optional): FollowIndirections value.
        """
        super().__init__()

        if isinstance(Criteria, SearchInfo):
            oth: SearchInfo = Criteria
            self.Criteria = oth.Criteria
            self.Recursion = oth.Recursion
            self.IncludeBase = oth.IncludeBase
            self.RespectFolderViewRestrictions = oth.RespectFolderViewRestrictions
            self.RespectDocViewRestrictions = oth.RespectDocViewRestrictions
            self.FollowIndirections = oth.FollowIndirections
            return

        kargs = {
            "Criteria": Criteria,
            "Recursion": Recursion,
            "IncludeBase": IncludeBase,
            "RespectFolderViewRestrictions": RespectFolderViewRestrictions,
            "RespectDocViewRestrictions": RespectDocViewRestrictions,
            "FollowIndirections": FollowIndirections,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._criteria = kwargs["Criteria"]
        self._recursion = kwargs["Recursion"]
        self._include_base = kwargs["IncludeBase"]
        self._respect_folder_view_restrictions = kwargs["RespectFolderViewRestrictions"]
        self._respect_doc_view_restrictions = kwargs["RespectDocViewRestrictions"]
        self._follow_indirections = kwargs["FollowIndirections"]


    @property
    def Criteria(self) -> typing.Tuple[SearchCriterium_c6d30c4c, ...]:
        """
        the search criteria.
        """
        return self._criteria

    @Criteria.setter
    def Criteria(self, value: typing.Tuple[SearchCriterium_c6d30c4c, ...]) -> None:
        self._criteria = value

    @property
    def Recursion(self) -> SearchRecursion_c7080c52:
        """
        the mode of recursion to use.
        """
        return self._recursion

    @Recursion.setter
    def Recursion(self, value: SearchRecursion_c7080c52) -> None:
        self._recursion = value

    @property
    def IncludeBase(self) -> bool:
        """
        whether to include the object itself in the search or only (some of) its sub-objects.
        """
        return self._include_base

    @IncludeBase.setter
    def IncludeBase(self, value: bool) -> None:
        self._include_base = value

    @property
    def RespectFolderViewRestrictions(self) -> bool:
        """
        whether to respect the \"view restrictions\" specified for the folders hierarchically contained within an object (e.g., only searches through subscribed folders).
        """
        return self._respect_folder_view_restrictions

    @RespectFolderViewRestrictions.setter
    def RespectFolderViewRestrictions(self, value: bool) -> None:
        self._respect_folder_view_restrictions = value

    @property
    def RespectDocViewRestrictions(self) -> bool:
        """
        whether to respect the \"view restrictions\" specified for the documents hierarchically contained within an object (e.g., only searches through marked documents).
        """
        return self._respect_doc_view_restrictions

    @RespectDocViewRestrictions.setter
    def RespectDocViewRestrictions(self, value: bool) -> None:
        self._respect_doc_view_restrictions = value

    @property
    def FollowIndirections(self) -> bool:
        """
        whether to follow indirections (link objects) and search through their respective targets also.
        """
        return self._follow_indirections

    @FollowIndirections.setter
    def FollowIndirections(self, value: bool) -> None:
        self._follow_indirections = value


__all__ = ['SearchInfo']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
import typing
from abc import abstractproperty
from ..awt.x_window import XWindow as XWindow_713b0924
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..frame.controller import Controller as Controller_a5330b37
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9

class OutlineView(Controller_a5330b37, XWindow_713b0924, XPropertySet_bc180bfa):
    """
    Service Class

    This component integrates an outline view to a presentation document into the desktop.
    
    In an outline view, the textual contents of presentation text objects from all presentation pages are presented as a continuous outline text.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API OutlineView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1OutlineView.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.OutlineView'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def VisibleArea(self) -> Rectangle_84b109e9:
        """
        This is the area that is currently visible.
        """
        ...


__all__ = ['OutlineView']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
from .x_module_ui_configuration_manager import XModuleUIConfigurationManager as XModuleUIConfigurationManager_873f1155
from .xui_configuration import XUIConfiguration as XUIConfiguration_c4eb0c34
from .xui_configuration_manager import XUIConfigurationManager as XUIConfigurationManager_24e20eef
from .xui_configuration_persistence import XUIConfigurationPersistence as XUIConfigurationPersistence_661010b9

class XModuleUIConfigurationManager2(XModuleUIConfigurationManager_873f1155, XUIConfiguration_c4eb0c34, XUIConfigurationManager_24e20eef, XUIConfigurationPersistence_661010b9):
    """
    Provides a unified interface for the ModuleUIConfigurationManager service.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API XModuleUIConfigurationManager2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XModuleUIConfigurationManager2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XModuleUIConfigurationManager2'


__all__ = ['XModuleUIConfigurationManager2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class WritingMode2(metaclass=UnoConstMeta, type_name="com.sun.star.text.WritingMode2", name_space="com.sun.star.text"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.text.WritingMode2``"""
        pass

    class WritingMode2Enum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.text.WritingMode2", name_space="com.sun.star.text"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.text.WritingMode2`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.text import WritingMode2 as WritingMode2
    else:
        # keep document generators happy
        from ...lo.text.writing_mode2 import WritingMode2 as WritingMode2

    class WritingMode2Enum(IntEnum):
        """
        Enum of Const Class WritingMode2

        this set of constants describes different writing directions
        
        In addition to numerous explicit writing directions, it allows to specify to take the writing direction from the object's context.
        
        **since**
        
            LibreOffice 6.3
        """
        LR_TB = WritingMode2.LR_TB
        """
        text within lines is written left-to-right.
        
        Lines and blocks are placed top-to-bottom.
        
        Typically, this is the writing mode for normal \"alphabetic\" text.
        """
        RL_TB = WritingMode2.RL_TB
        """
        text within a line are written right-to-left.
        
        Lines and blocks are placed top-to-bottom.
        
        Typically, this writing mode is used in Arabic and Hebrew text.
        """
        TB_RL = WritingMode2.TB_RL
        """
        text within a line is written top-to-bottom.
        
        Lines and blocks are placed right-to-left.
        
        Typically, this writing mode is used in Chinese and Japanese text.
        """
        TB_LR = WritingMode2.TB_LR
        """
        text within a line is written top-to-bottom.
        
        Lines and blocks are placed left-to-right.
        
        Typically, this writing mode is used in Mongolian text.
        """
        PAGE = WritingMode2.PAGE
        """
        obtain writing mode from the current page.
        
        May not be used in page styles.
        """
        CONTEXT = WritingMode2.CONTEXT
        """
        obtain actual writing mode from the context of the object.
        """
        BT_LR = WritingMode2.BT_LR
        """
        text within a line is written bottom-to-top.
        
        Lines and blocks are placed left-to-right.
        
        **since**
        
            LibreOffice 6.3
        """

__all__ = ['WritingMode2', 'WritingMode2Enum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility


class AccessibleTextType(object):
    """
    Const Class

    Collection of types of text portions.
    
    This collection describes the types of text portions that can be accessed with the help of the methods of the XAccessibleText interface.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleTextType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1accessibility_1_1AccessibleTextType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.AccessibleTextType'
    __ooo_type_name__: str = 'const'

    CHARACTER = 1
    """
    Single character.
    
    Indicates that single (multibyte) characters are used.
    """
    WORD = 2
    """
    Single word.
    
    Indicates that single words are used. The definition of what a word is, is implementation and language/locale dependent. While in English a word is ended by a space or a special character like a comma or a period, this is not necessarily true in other languages.
    """
    SENTENCE = 3
    """
    Single sentence.
    
    Indicates that single sentences are used. The definition of what a sentence is, is implementation and language/locale dependent. While in English a sentence is ended by a period, this is not necessarily true in other languages.
    """
    PARAGRAPH = 4
    """
    Single paragraph.
    
    Indicates that single paragraphs are used. The definition of what a paragraph is, is implementation and language/locale dependent.
    """
    LINE = 5
    """
    Single line.
    
    Indicates that single lines, as displayed on the screen, are used. In contrast to the constants CHARACTER, WORD, SENTENCE, and PARAGRAPH which are content oriented this constant is view oriented. It can be used to retrieve hyphenation information.
    """
    GLYPH = 6
    """
    Single glyph.
    
    Glyphs are runs of one or more (multibyte) characters which are displayed as one symbol.
    """
    ATTRIBUTE_RUN = 7
    """
    Attribute run.
    
    Each attribute run is a character run of maximal length where all characters have the same attributes set.
    """

__all__ = ['AccessibleTextType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XStateChangeListener(XEventListener_c7230c4a):
    """
    makes it possible to receive events when an embedded object changes it's state.

    See Also:
        `API XStateChangeListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XStateChangeListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XStateChangeListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XStateChangeListener'

    @abstractmethod
    def changingState(self, aEvent: EventObject_a3d70b03, nOldState: int, nNewState: int) -> None:
        """
        is called just before the object changes state.
        
        Actually the listener can try to complain about state changing, but it is up to object to decide whether the state change can be prevented. Anyway the possibility to complain must be used very carefully.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def stateChanged(self, aEvent: EventObject_a3d70b03, nOldState: int, nNewState: int) -> None:
        """
        is called after the object has changed state.
        """
        ...

__all__ = ['XStateChangeListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uno
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_reference import XReference as XReference_8ecb0a41

class XAdapter(XInterface_8f010a43):
    """
    This is the server-side interface to a weak adapter.
    
    The implementation of XAdapter must know but not hold the adapted object, because it must not affect the lifetime of the adapted object.

    See Also:
        `API XAdapter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uno_1_1XAdapter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uno'
    __ooo_full_ns__: str = 'com.sun.star.uno.XAdapter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.uno.XAdapter'

    @abstractmethod
    def addReference(self, xRef: XReference_8ecb0a41) -> None:
        """
        adds a reference to the adapter.
        
        All added references are called when the adapted object dies.
        """
        ...
    @abstractmethod
    def queryAdapted(self) -> XInterface_8f010a43:
        """
        queries the adapted object if it is alive.
        """
        ...
    @abstractmethod
    def removeReference(self, xRef: XReference_8ecb0a41) -> None:
        """
        removes a reference from the adapter.
        """
        ...

__all__ = ['XAdapter']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart


class DataLabelPlacement(object):
    """
    Const Class

    These values specify where the captions/labels of data points are displayed.
    
    **since**
    
        LibreOffice 7.0

    See Also:
        `API DataLabelPlacement <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart_1_1DataLabelPlacement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.DataLabelPlacement'
    __ooo_type_name__: str = 'const'

    AVOID_OVERLAP = 0
    CENTER = 1
    TOP = 2
    TOP_LEFT = 3
    LEFT = 4
    BOTTOM_LEFT = 5
    BOTTOM = 6
    BOTTOM_RIGHT = 7
    RIGHT = 8
    TOP_RIGHT = 9
    INSIDE = 10
    OUTSIDE = 11
    NEAR_ORIGIN = 12
    CUSTOM = 13

__all__ = ['DataLabelPlacement']
